==> FHLBBS-5.3.tgz: php/chat.php <==
<?php
 require("config.php");
 require("wbbs.php");
 require("auth.php");
 session_register("userid","cuser","caller");
 $now=date("m/d/Y H:i:s D");
 $tyn=(int) $_REQUEST["YN"];
 if ($tyn==1) //nchat
 {
	 //ˬdv
	if (!HAS_PERM(PERM_LOGINOK))
                die ("zT{|qLALkiJѫǡI");
	$genbuf=$CHATDIR."/main";
	if (is_file($genbuf))
	{
	 	$data=file($genbuf);
		if (in_array("{$cuser->userid}\n",$data))
		    die("IAwgbѫṊ̀FI");
		$cnt=count($data);
		for ($i=0;$i<$cnt;$i=$i+1) //qjaAӤF
		{
			$genbuf1=sethomefile(trim($data[$i]),"chat_data");
			if (($fp= fopen($genbuf1, "a")) !== false)
			{
				fwrite($fp,"<font color=\"red\"> {$cuser->userid}</font><font color=\"blue\"> iJ[FHL Chat] ][</font>\n");
				fclose($fp);
			}
		
		}
	}
	if (($fp= fopen($genbuf, "a")) === false)
		die ("tɮ $genbuf Lk}ҡI");
	fwrite($fp,"{$cuser->userid}\n");
	fclose($fp);
	$genbuf=sethomefile($cuser->userid,"chat_data");
	if (($fp= fopen($genbuf, "w")) === false)
                die ("tɮ $genbuf Lk}ҡI");
        else
	{
		fwrite($fp,"<font color=\"red\"> {$cuser->userid}</font><font color=\"blue\"> iJ[FHL Chat] ][</font>\n");
		fclose($fp);
	}
	header("Location: /php/chat.php?YN=4");
 }
 elseif ($tyn==2) //Jchat
 {
	if (!HAS_PERM(PERM_LOGINOK))
                die ("zT{|qLALkiJѫǡI");
	$genbuf=$CHATDIR."/main";
	$inp=$_REQUEST["word"];
	if (is_file($genbuf))
	{
	 	$data=file($genbuf);
		$newdata=array();
		if (!in_array("{$cuser->userid}\n",$data))
		    die("IAbѫǤI");
		$cnt=count($data);
		$j=0;
		$deluser="";
		for ($i=0;$i<$cnt;$i=$i+1) //gJjaɮפ
		{
			$act_file=$BBSHOME."/active/".trim($data[$i]);
			$genbuf=sethomefile(trim($data[$i]),"chat_data");
			if (is_file($act_file))
			{
			   if (($fp= fopen($genbuf, "a")) !== false)
			   {
   				fwrite($fp,"{$cuser->userid}: {$inp}\n");
   				fclose($fp);
			   }
			   $newdata[$j]=$data[$i];
			   $j=$j+1;
			}
			else
			{
				unlink($genbuf);
				$deluser=$deluser.trim($data[$i])." ";
			}
		}
		//pGHQRFANg mainɮ
		if ($cnt!=count($newdata))
		{
		    $genbuf=$CHATDIR."/main";
		    $genbuf1=$CHATDIR."/main.bak";
		    if (($fp= fopen($genbuf1, "w")) !== false)
	 	    {   
		       $cnt=count($newdata);
		        for ($i=0;$i<$cnt;$i=$i+1) //ۤvAqOH
		        {
   		   	    fwrite($fp,$newdata[$i]);
			     $gen=sethomefile(trim($newdata[$i]),"chat_data");
			     if (($fp1= fopen($gen, "a")) !== false)
			    {
   				fwrite($fp1,"<font color=\"red\">{$deluser} mӤ[AQXhF</font>\n");
   				fclose($fp1);
			    }
		        }
		     }
   		    fclose($fp);
		    rename($genbuf1,$genbuf);
		}
	} //is_file(genbuf)
   	header("Location: /chat2.html");
 }
 elseif ($tyn==3) //}chat
 {
	$genbuf=$CHATDIR."/main";
	$genbuf1=$CHATDIR."/main.bak";
	if (is_file($genbuf))
	{
	 	$data=file($genbuf);
		if (($fp= fopen($genbuf1, "w")) !== false)
		{
		   $cnt=count($data);
		   for ($i=0;$i<$cnt;$i=$i+1) //ۤvAqOH
		   {
		      if (strcasecmp("{$cuser->userid}\n",$data[$i])!=0)
		      {
   		   	fwrite($fp,$data[$i]);
			$gen=sethomefile(trim($data[$i]),"chat_data");
			if (($fp1= fopen($gen, "a")) !== false)
			{
   				fwrite($fp1,"<font color=\"red\">{$cuser->userid}: }F</font>\n");
   				fclose($fp1);
			}
		      }
		   }
		}
   		fclose($fp);
        }
	rename($genbuf1,$genbuf);
	$t1 = time();
        $t2 = date("D M d H:i:s Y");
        $gen=sethomefile($cuser->userid,"chat_data");
        $filename2="M.{$t1}.A";
        $receiver=$cuser->userid;
        $filename1=sethomefile($receiver,$filename2);
        if (($fptr2 = fopen($filename1,"w"))===false)
                die ("S{$receiver}oӤHI<p>\n");
        $genbuf=sprintf("@: %s(%s)\n",$cuser->userid,$cuser->username);
            fwrite($fptr2,$genbuf);
        fwrite($fptr2,"D: |ĳO\n");
        fwrite($fptr2,"ɶ: {$t2}\n\n");
        fwrite($fptr2,join ('', file ($gen)));
        fclose($fptr2);
        $postfile=new dirrec;
        $postfile->filename=$filename2;
        $postfile->owner="[..]";
        $postfile->title="|ĳO";
        /*** gY ***/
        $postfile->date=date("m/d");
        if (strlen($postfile->date)==4) $postfile->date=" ".$postfile->date;
        $buf1=sethomedir($receiver);
        $numposts = (int) filesize($buf1)/$dirlength;
        $postfile->substitute_record($buf1,$numposts+1);
         echo "<script LANGUAGE=\"JavaScript\" FOR=\"window\" EVENT=\"onload()\">\n parent.window.close() </script>";
        die("");

 }
 elseif ($tyn==4) //display chat
 {
 	echo "<META HTTP-EQUIV=\"Refresh\" Content=\"15\">";
	$genbuf=sethomefile($cuser->userid,"chat_data");
	 $data=file($genbuf);
        $cnt=count($data);
        $cnt=$cnt-1;
        $bg=$cnt-$CHATNUM;
        if ($bg<0) $bg=0;
        for ($i=$bg;$i<=$cnt;$i=$i+1)
                echo "{$data[$i]}<br>\n";
 }
?>

==> FHLBBS-5.4.tgz: php/chat.php <==
<?php
 require("config.php");
 require("wbbs.php");
 require("auth.php");
 session_register("userid","cuser","caller");
 $now=date("m/d/Y H:i:s D");
 $tyn=(int) $_REQUEST["YN"];
 if ($tyn==1) //nchat
 {
	 //ˬdv
	if (!HAS_PERM(PERM_LOGINOK))
                die ("zT{|qLALkiJѫǡI");
	$genbuf=$CHATDIR."/main";
	if (is_file($genbuf))
	{
	 	$data=file($genbuf);
		if (in_array("{$cuser->userid}\n",$data))
		    die("IAwgbѫṊ̀FI");
		$cnt=count($data);
		for ($i=0;$i<$cnt;$i=$i+1) //qjaAӤF
		{
			$genbuf1=sethomefile(trim($data[$i]),"chat_data");
			if (($fp= fopen($genbuf1, "a")) !== false)
			{
				fwrite($fp,"<font color=\"red\"> {$cuser->userid}</font><font color=\"blue\"> iJ[FHL Chat] ][</font>\n");
				fclose($fp);
			}
		
		}
	}
	if (($fp= fopen($genbuf, "a")) === false)
		die ("tɮ $genbuf Lk}ҡI");
	fwrite($fp,"{$cuser->userid}\n");
	fclose($fp);
	$genbuf=sethomefile($cuser->userid,"chat_data");
	if (($fp= fopen($genbuf, "w")) === false)
                die ("tɮ $genbuf Lk}ҡI");
        else
	{
		fwrite($fp,"<font color=\"red\"> {$cuser->userid}</font><font color=\"blue\"> iJ[FHL Chat] ][</font>\n");
		fclose($fp);
	}
	header("Location: /php/chat.php?YN=4");
 }
 elseif ($tyn==2) //Jchat
 {
	if (!HAS_PERM(PERM_LOGINOK))
                die ("zT{|qLALkiJѫǡI");
	$genbuf=$CHATDIR."/main";
	$inp=$_REQUEST["word"];
	if (is_file($genbuf))
	{
	 	$data=file($genbuf);
		$newdata=array();
		if (!in_array("{$cuser->userid}\n",$data))
		    die("IAbѫǤI");
		$cnt=count($data);
		$j=0;
		$deluser="";
		for ($i=0;$i<$cnt;$i=$i+1) //gJjaɮפ
		{
			$act_file=$BBSHOME."/active/".trim($data[$i]);
			$genbuf=sethomefile(trim($data[$i]),"chat_data");
			if (is_file($act_file))
			{
			   if (($fp= fopen($genbuf, "a")) !== false)
			   {
   				fwrite($fp,"{$cuser->userid}: {$inp}\n");
   				fclose($fp);
			   }
			   $newdata[$j]=$data[$i];
			   $j=$j+1;
			}
			else
			{
				unlink($genbuf);
				$deluser=$deluser.trim($data[$i])." ";
			}
		}
		//pGHQRFANg mainɮ
		if ($cnt!=count($newdata))
		{
		    $genbuf=$CHATDIR."/main";
		    $genbuf1=$CHATDIR."/main.bak";
		    if (($fp= fopen($genbuf1, "w")) !== false)
	 	    {   
		       $cnt=count($newdata);
		        for ($i=0;$i<$cnt;$i=$i+1) //ۤvAqOH
		        {
   		   	    fwrite($fp,$newdata[$i]);
			     $gen=sethomefile(trim($newdata[$i]),"chat_data");
			     if (($fp1= fopen($gen, "a")) !== false)
			    {
   				fwrite($fp1,"<font color=\"red\">{$deluser} mӤ[AQXhF</font>\n");
   				fclose($fp1);
			    }
		        }
		     }
   		    fclose($fp);
		    rename($genbuf1,$genbuf);
		}
	} //is_file(genbuf)
   	header("Location: /chat2.html");
 }
 elseif ($tyn==3) //}chat
 {
	$genbuf=$CHATDIR."/main";
	$genbuf1=$CHATDIR."/main.bak";
	if (is_file($genbuf))
	{
	 	$data=file($genbuf);
		if (($fp= fopen($genbuf1, "w")) !== false)
		{
		   $cnt=count($data);
		   for ($i=0;$i<$cnt;$i=$i+1) //ۤvAqOH
		   {
		      if (strcasecmp("{$cuser->userid}\n",$data[$i])!=0)
		      {
   		   	fwrite($fp,$data[$i]);
			$gen=sethomefile(trim($data[$i]),"chat_data");
			if (($fp1= fopen($gen, "a")) !== false)
			{
   				fwrite($fp1,"<font color=\"red\">{$cuser->userid}: }F</font>\n");
   				fclose($fp1);
			}
		      }
		   }
		}
   		fclose($fp);
        }
	rename($genbuf1,$genbuf);
	$t1 = time();
        $t2 = date("D M d H:i:s Y");
        $gen=sethomefile($cuser->userid,"chat_data");
        $filename2="M.{$t1}.A";
        $receiver=$cuser->userid;
        $filename1=sethomefile($receiver,$filename2);
        if (($fptr2 = fopen($filename1,"w"))===false)
                die ("S{$receiver}oӤHI<p>\n");
        $genbuf=sprintf("@: %s(%s)\n",$cuser->userid,$cuser->username);
            fwrite($fptr2,$genbuf);
        fwrite($fptr2,"D: |ĳO\n");
        fwrite($fptr2,"ɶ: {$t2}\n\n");
        fwrite($fptr2,join ('', file ($gen)));
        fclose($fptr2);
        $postfile=new dirrec;
        $postfile->filename=$filename2;
        $postfile->owner="[..]";
        $postfile->title="|ĳO";
        /*** gY ***/
        $postfile->date=date("m/d");
        if (strlen($postfile->date)==4) $postfile->date=" ".$postfile->date;
        $buf1=sethomedir($receiver);
        $numposts = (int) filesize($buf1)/$dirlength;
        $postfile->substitute_record($buf1,$numposts+1);
         echo "<script LANGUAGE=\"JavaScript\">\n parent.window.close() </script>";
        die("");

 }
 elseif ($tyn==4) //display chat
 {
 	echo "<META HTTP-EQUIV=\"Refresh\" Content=\"15\">";
	$genbuf=sethomefile($cuser->userid,"chat_data");
	 $data=file($genbuf);
        $cnt=count($data);
        $cnt=$cnt-1;
        $bg=$cnt-$CHATNUM;
        if ($bg<0) $bg=0;
        for ($i=$bg;$i<=$cnt;$i=$i+1)
                echo "{$data[$i]}<br>\n";
 }
?>
